pub enum ImplicitPoint {
Explicit([f64; 3]),
Lpi(Lpi),
Tpi(Tpi),
}Expand description
A point that is either an explicit input coordinate or an implicit intersection point carried symbolically over the original input coords.
Variants
Explicit([f64; 3])
Lpi(Lpi)
Line PQ ∩ plane RST.
Tpi(Tpi)
Three planes concurrent (each a triangle: 3 points).