pub struct InstanceTemplate {
pub rep_identity: u128,
pub template_index: usize,
pub occurrences: Vec<InstanceOccurrence>,
}Expand description
A unique geometry shared by two or more occurrences.
Fields
rep_identity: u128Representation-identity key (RepresentationMap id for mapped items).
template_index: usizeIndex of the mesh whose geometry is the template to upload.
occurrences: Vec<InstanceOccurrence>Every occurrence (including the template itself, with identity transform).