ClippingProcessor

Struct ClippingProcessor 

pub struct ClippingProcessor {
    pub epsilon: f64,
}
CSG Clipping Processor

Fields

epsilon: f64

Epsilon for floating point comparisons

Implementations

Source

impl ClippingProcessor

pub fn new() -> Self

Create a new clipping processor

pub fn clip_triangle(&self, triangle: &Triangle, plane: &Plane) -> ClipResult

Clip a triangle against a plane Returns triangles that are in front of the plane

pub fn subtract_box( &self, mesh: &Mesh, min: Point3<f64>, max: Point3<f64>, ) -> Result<Mesh>

Box subtraction - removes everything inside the box from the mesh Uses proper CSG difference operation via subtract_mesh

pub fn subtract_mesh( &self, host_mesh: &Mesh, opening_mesh: &Mesh, ) -> Result<Mesh>

Subtract opening mesh from host mesh using BSP CSG boolean operations

pub fn union_mesh(&self, mesh_a: &Mesh, mesh_b: &Mesh) -> Result<Mesh>

Union two meshes together using BSP CSG boolean operations

pub fn intersection_mesh(&self, mesh_a: &Mesh, mesh_b: &Mesh) -> Result<Mesh>

Intersect two meshes using BSP CSG boolean operations

Returns the intersection of two meshes (the volume where both overlap).

pub fn union_meshes(&self, meshes: &[Mesh]) -> Result<Mesh>

Union multiple meshes together

Convenience method that sequentially unions all non-empty meshes. Skips empty meshes to avoid unnecessary CSG operations.

pub fn subtract_meshes_batched( &self, host: &Mesh, voids: &[Mesh], ) -> Result<Mesh>

Subtract multiple meshes efficiently

When void count exceeds threshold, unions all voids first then performs a single subtraction. This is much more efficient for elements with many openings (e.g., floors with many penetrations).

Arguments
  • host - The host mesh to subtract from
  • voids - List of void meshes to subtract
Returns

The host mesh with all voids subtracted

pub fn subtract_meshes_with_fallback(&self, host: &Mesh, voids: &[Mesh]) -> Mesh

Subtract meshes with fallback on failure

Attempts batched subtraction, but if it fails, returns the host mesh unchanged rather than propagating the error. This provides graceful degradation for problematic void geometries.

pub fn clip_mesh_with_box( &self, mesh: &Mesh, min: Point3<f64>, max: Point3<f64>, ) -> Result<Mesh>

👎Deprecated:

Use subtract_box() for better performance

Clip mesh using bounding box (6 planes) - DEPRECATED: use subtract_box() instead Subtracts everything inside the box from the mesh

pub fn clip_mesh(&self, mesh: &Mesh, plane: &Plane) -> Result<Mesh>

Clip an entire mesh against a plane